==> libharu-2.4.2.tar.gz: libharu-2.4.2/include/hpdf_config.h.cmake <==
/* Define to 1 if you have the <dlfcn.h> header file. */
#cmakedefine LIBHPDF_HAVE_DLFCN_H

/* Define to 1 if you have the <inttypes.h> header file. */
#cmakedefine LIBHPDF_HAVE_INTTYPES_H

/* Define to 1 if you have the `png' library (-lpng). */
#cmakedefine LIBHPDF_HAVE_LIBPNG

/* Define to 1 if you have the `z' library (-lz). */
#cmakedefine LIBHPDF_HAVE_LIBZ

/* Define to 1 if you have the <memory.h> header file. */
#cmakedefine LIBHPDF_HAVE_MEMORY_H

/* Define to 1 if you have the <stdint.h> header file. */
#cmakedefine LIBHPDF_HAVE_STDINT_H

/* Define to 1 if you have the <stdlib.h> header file. */
#cmakedefine LIBHPDF_HAVE_STDLIB_H

/* Define to 1 if you have the <strings.h> header file. */
#cmakedefine LIBHPDF_HAVE_STRINGS_H

/* Define to 1 if you have the <string.h> header file. */
#cmakedefine LIBHPDF_HAVE_STRING_H

/* Define to 1 if you have the <sys/stat.h> header file. */
#cmakedefine LIBHPDF_HAVE_SYS_STAT_H

/* Define to 1 if you have the <sys/types.h> header file. */
#cmakedefine LIBHPDF_HAVE_SYS_TYPES_H

/* Define to 1 if you have the <unistd.h> header file. */
#cmakedefine LIBHPDF_HAVE_UNISTD_H

/* debug build */
#cmakedefine LIBHPDF_DEBUG

/* debug trace enabled */
#cmakedefine LIBHPDF_DEBUG_TRACE

/* Define to the address where bug reports for this package should be sent. */
#cmakedefine LIBHPDF_PACKAGE_BUGREPORT "@LIBHPDF_PACKAGE_BUGREPORT@"

/* Define to the full name of this package. */
#cmakedefine LIBHPDF_PACKAGE_NAME "@LIBHPDF_PACKAGE_NAME@"

/* Define to the full name and version of this package. */
#cmakedefine LIBHPDF_PACKAGE_STRING "@LIBHPDF_PACKAGE_STRING@"

/* Define to the one symbol short name of this package. */
#cmakedefine LIBHPDF_PACKAGE_TARNAME "@LIBHPDF_PACKAGE_TARNAME@"

/* Define to the version of this package. */
#cmakedefine LIBHPDF_PACKAGE_VERSION "@LIBHPDF_PACKAGE_VERSION@"

/* Define to 1 if you have the ANSI C header files. */
#cmakedefine LIBHPDF_STDC_HEADERS

/* Define to `unsigned int' if <sys/types.h> does not define. */
#cmakedefine LIBHPDF_size_t @LIBHPDF_size_t@

==> libharu-2.4.3.tar.gz: libharu-2.4.3/include/hpdf_config.h.cmake <==
/* Define to 1 if you have the <dlfcn.h> header file. */
#cmakedefine LIBHPDF_HAVE_DLFCN_H

/* Define to 1 if you have the <inttypes.h> header file. */
#cmakedefine LIBHPDF_HAVE_INTTYPES_H

/* Define to 1 if you have the `png' library (-lpng). */
#cmakedefine LIBHPDF_HAVE_LIBPNG

/* Define to 1 if you have the `z' library (-lz). */
#cmakedefine LIBHPDF_HAVE_ZLIB

/* Define to 1 if you have the <memory.h> header file. */
#cmakedefine LIBHPDF_HAVE_MEMORY_H

/* Define to 1 if you have the <stdint.h> header file. */
#cmakedefine LIBHPDF_HAVE_STDINT_H

/* Define to 1 if you have the <stdlib.h> header file. */
#cmakedefine LIBHPDF_HAVE_STDLIB_H

/* Define to 1 if you have the <strings.h> header file. */
#cmakedefine LIBHPDF_HAVE_STRINGS_H

/* Define to 1 if you have the <string.h> header file. */
#cmakedefine LIBHPDF_HAVE_STRING_H

/* Define to 1 if you have the <sys/stat.h> header file. */
#cmakedefine LIBHPDF_HAVE_SYS_STAT_H

/* Define to 1 if you have the <sys/types.h> header file. */
#cmakedefine LIBHPDF_HAVE_SYS_TYPES_H

/* Define to 1 if you have the <unistd.h> header file. */
#cmakedefine LIBHPDF_HAVE_UNISTD_H

/* debug build */
#cmakedefine LIBHPDF_DEBUG

/* debug trace enabled */
#cmakedefine LIBHPDF_DEBUG_TRACE

/* Define to the address where bug reports for this package should be sent. */
#cmakedefine LIBHPDF_PACKAGE_BUGREPORT "@LIBHPDF_PACKAGE_BUGREPORT@"

/* Define to the full name of this package. */
#cmakedefine LIBHPDF_PACKAGE_NAME "@LIBHPDF_PACKAGE_NAME@"

/* Define to the full name and version of this package. */
#cmakedefine LIBHPDF_PACKAGE_STRING "@LIBHPDF_PACKAGE_STRING@"

/* Define to the one symbol short name of this package. */
#cmakedefine LIBHPDF_PACKAGE_TARNAME "@LIBHPDF_PACKAGE_TARNAME@"

/* Define to the version of this package. */
#cmakedefine LIBHPDF_PACKAGE_VERSION "@LIBHPDF_PACKAGE_VERSION@"

/* Define to 1 if you have the ANSI C header files. */
#cmakedefine LIBHPDF_STDC_HEADERS

/* Define to `unsigned int' if <sys/types.h> does not define. */
#cmakedefine LIBHPDF_size_t @LIBHPDF_size_t@
